.. _spkg_async_lru:

async_lru: Simple LRU cache for asyncio
=======================================

Description
-----------

Simple LRU cache for asyncio

License
-------

MIT License

Upstream Contact
----------------

https://pypi.org/project/async-lru/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2.0.5

version_requirements.txt::

    async-lru

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install async-lru

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i async_lru


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
